@@ -66,7 +66,7 @@ class WorkerRedis():
             key = __.get(message, dkey, None)
             value = __.get(message, dvalue, None)
             
-            if key and value:
+            if key and (value is not None):
                 if prefix:
                     key = prefix + '_' + key
                 if suffix:
@@ -136,4 +136,3 @@ class WorkerRedis():
             self.initializeRedis()
 
             
-
